OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "Bruger-Sessionen udløb uventet",
    "Provided email-address is not valid" : "Leveret e-mailadresse er ikke gyldig ",
    "%s has published the calendar »%s«" : "%s har oprettet en begivenhed i kalenderen »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Uventet fejl ved afsendelse, venligst kontakt din administrator",
    "Hello," : "Hej,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Vi ønkser at informerer dig om at %s har oprettet en begivenhed i kalenderen »%s«.",
    "Open »%s«" : "Åbn »%s«",
    "Cheers!" : "Hav en fortsat god dag.",
    "Calendar" : "Kalender",
    "A Calendar app for Nextcloud" : "En kalender-app til Nextcloud",
    "Previous day" : "Forrige dag",
    "Previous week" : "Forrige uge",
    "Previous month" : "Forrige måned",
    "Next day" : "Næste dag",
    "Next week" : "Næste uge",
    "Next month" : "Næste måned",
    "+ New event" : "+ Ny begivenhed",
    "Today" : "I dag",
    "Day" : "Dag",
    "Week" : "Uge",
    "Month" : "Måned",
    "Untitled calendar" : "Unanvngiven kalender",
    "Edit name" : "Rediger navn",
    "Saving name …" : "Gemmer navn…",
    "Edit color" : "Rediger farve",
    "Saving color …" : "Gemmer farve…",
    "Copy private link" : "Kopier privat link",
    "Download" : "Hent",
    "Unshare from me" : "Fjern deling fra mig",
    "Delete" : "Slet",
    "An error occurred, unable to change visibility of the calendar." : "Kalenderens synlighed kunne ikke ændres.",
    "An error occurred, unable to delete the calendar." : "Kalenderen kunne ikke slettes.",
    "Calendar link copied to clipboard." : "Kalender link kopieret.",
    "Calendar link could not be copied to clipboard." : "Kalender link kunne ikke kopieres.",
    "An error occurred, unable to rename the calendar." : "Kalenderen kunne ikke omdøbes.",
    "An error occurred, unable to change the calendar's color." : "Kalenderens farve kunne ikke ændres.",
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Kalenderen bliver slettet om {countdown} sekunder","Kalenderen bliver slettet om {countdown} sekunder"],
    "Share link" : "Del link",
    "Publish calendar" : "Udgiv kalender",
    "Publishing calendar" : "Udgiver kalender",
    "Copy public link" : "Kopier offentligt link",
    "Send link to calendar via email" : "Send link til kalender via e-mail",
    "Sending email …" : "Sender email…",
    "Copy subscription link" : "Kopier abonnementslink",
    "Copying link …" : "Kopierer link…",
    "Copied link" : "Link kopieret",
    "Could not copy link" : "Link kunne ikke kopieres",
    "Copy embedding code" : "Kopier indlejringskode",
    "Copying code …" : "Kopierer kode…",
    "Copied code" : "Kode kopieret",
    "Could not copy code" : "Kode kunne ikke kopieres",
    "Delete share link" : "Slet delingslink",
    "Deleting share link …" : "Sletter delingslink…",
    "An error occurred, unable to publish calendar." : "Kalenderen kunne ikke udgives",
    "Embed code copied to clipboard." : "Indlejringskode kopieret til udklipsholder.",
    "Share with users or groups" : "Del med brugere eller grupper",
    "No users or groups" : "Ingen brugere eller grupper",
    "can edit" : "kan redigere",
    "+ New calendar" : "+ Ny kalender",
    "New calendar" : "Ny kalender",
    "Creating calendar …" : "Opretter kalender…",
    "New calendar with task list" : "Ny kalender med opgaveliste",
    "Creating subscription …" : "Opretter abonnement…",
    "Import calendars" : "Importer kalendere",
    "Filename" : "Filnavn",
    "Cancel" : "Annullér",
    "_Import calendar_::_Import calendars_" : ["Importer kalender","Importer kalendere"],
    "Automatic" : "Automatisk",
    "or" : "eller",
    "Actions" : "Handlinger",
    "Enable birthday calendar" : "Slå fødselsdagskalender til",
    "Enable simplified editor" : "Slå simpel editor til",
    "Show weekends" : "Vis weekender",
    "Show week numbers" : "Vis ugenummer ",
    "Copy primary CalDAV address" : "Kopier primær CalDAV-adresse",
    "Settings & import" : "Indstillinger & importer",
    "Notification" : "Notifikation",
    "Email" : "E-mail",
    "_second_::_seconds_" : ["sekund","sekunder"],
    "_minute_::_minutes_" : ["minut","minutter"],
    "_hour_::_hours_" : ["time","timer"],
    "_day_::_days_" : ["dag","dage"],
    "_week_::_weeks_" : ["uge","uger"],
    "Busy" : "Optaget",
    "Unknown" : "Ukendt",
    "Create Talk room for this event" : "Opret Snak rum for denne begivenhed",
    "Event title" : "Titel",
    "All day" : "Hele dagen",
    "from {startDate}" : "fra {startDate}",
    "from {startDate} at {startTime}" : "fra {startDate} kl {startTime}",
    "to {endDate}" : "til {endDate}",
    "to {endDate} at {endTime}" : "til {endDate} kl {endTime}",
    "Repeat" : "Gentag",
    "Save" : "Gem",
    "never" : "aldrig",
    "after" : "efter",
    "first" : "første",
    "third" : "tredje",
    "fourth" : "fjerde",
    "fifth" : "femte",
    "second to last" : "næstsidste",
    "last" : "sidste",
    "_month_::_months_" : ["måned","måneder"],
    "_year_::_years_" : ["år","år"],
    "Monday" : "Mandag",
    "weekday" : "hverdag",
    "weekend day" : "weekenddag",
    "More" : "Mere",
    "Update" : "Opdatér",
    "Global" : "Global",
    "Personal" : "Personlig",
    "Details" : "Detaljer",
    "Attendees" : "Deltagere",
    "Close" : "Luk",
    "Anniversary" : "Årsdag",
    "Week {number} of {year}" : "Uge {number} i {year}",
    "Daily" : "Dagligt",
    "Weekly" : "Ugentligt",
    "Untitled event" : "Unavngiven begivenhed",
    "When shared show full event" : "Når delt, vis den fulde begivenhed",
    "When shared show only busy" : "Når delt, vis kun optaget",
    "When shared hide this event" : "Når delt, skjul denne begivenhed",
    "Location" : "Sted",
    "Description" : "Beskrivelse",
    "Status" : "Status",
    "Confirmed" : "Bekræftet",
    "Tentative" : "Foreløbig",
    "Categories" : "Kategorier",
    "Presentation" : "Præsentation",
    "Movie" : "Film",
    "Review" : "Gennemse",
    "Office" : "Kontor",
    "Mail" : "Mail"
},
"nplurals=2; plural=(n != 1);");
